@@ -14,15 +14,10 @@ package com.ibm.as400.access;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
-import java.sql.Array;
-import java.sql.Blob;
-import java.sql.Clob;
-import java.sql.Date;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Time;
-import java.sql.Timestamp;
-import java.sql.Types;
+import java.sql.*;
+
+
+
 
 // @array new class
 /**
@@ -107,14 +102,18 @@ public class AS400JDBCArray implements Array {
     }
 
     con_ = con; // @arrayrs
-
-    if (data_.length > 0 && isSQLData_ && data_[0] != null) // @nullelem
-      contentTemplate_ = (SQLData) data_[0];
-    else
+    contentTemplate_ = null; 
+    for (int  i = 0; isSQLData_ && (contentTemplate_ == null) && (i < data_.length); i++) { 
+      if (data_[i] != null)  { 
+        contentTemplate_ = (SQLData) data_[i];
+      }
+    }
+    if (contentTemplate_ == null ) { 
       contentTemplate_ = SQLDataFactory.newData(typeName, 1, 1, 1, 37, null,
           vrm_, (con == null ? null : con.getProperties())); // @array
     // allow max for local conversion only since it is not associated with a
     // column on hostserver yet
+    }
   }
 
   /**
@@ -1924,7 +1923,7 @@ public class AS400JDBCArray implements Array {
                         "DB2Array.validate 07006 type is DECIMAL/NUMERIC/DECFLOAT but NumberFormatException thrown for string "
                             + inStringArray[i]);
               }
-              JDError.throwSQLException(JDError.EXC_DATA_TYPE_MISMATCH,"DECIMAL("+inStringArray+")");
+              JDError.throwSQLException(JDError.EXC_DATA_TYPE_MISMATCH,"DECIMAL["+i+"]("+inStringArray[i]+")");
               return;
 
             }
@@ -2024,28 +2023,41 @@ public class AS400JDBCArray implements Array {
       }
       break;
 
-    /*
-     * ifdef JDBC40
-     * 
-     * case 2009: // Types.SQLXML { boolean allValid = true; String subArrayType
-     * = "";
-     * 
-     * Object[] inSQLXMLArray = (Object[]) inArray; SQLXML[] SQLXMLArray = new
-     * SQLXML[inSQLXMLArray.length]; for (int i = 0; allValid && i <
-     * inSQLXMLArray.length; i++) { if ( inSQLXMLArray[i] == null) {
-     * SQLXMLArray[i] = null; } else { if ( inSQLXMLArray[i] instanceof SQLXML )
-     * { SQLXMLArray[i] = (SQLXML) inSQLXMLArray[i]; } else { subArrayType =
-     * inSQLXMLArray[i].getClass().getName(); allValid = false; } } }
-     * 
-     * if (allValid) { data_ =SQLXMLArray;
-     * 
-     * } else { if (JDTrace.isTraceOn()) { JDTrace.logInformation(this,
-     * "DB2Array.validate 07006 type is SQLXML but array types is "
-     * +arrayType+" subArrayType = "+subArrayType); }
-     * JDError.throwSQLException(JDError.EXC_DATA_TYPE_MISMATCH); } } break;
-     * 
-     * endif
-     */
+    /* ifdef JDBC40 
+      case 2009: // Types.SQLXML 
+      { 
+        boolean allValid = true; 
+        String subArrayType = "";
+     
+        Object[] inSQLXMLArray = (Object[]) inArray; 
+        SQLXML[] SQLXMLArray = new SQLXML[inSQLXMLArray.length]; 
+        for (int i = 0; allValid && i < inSQLXMLArray.length; i++) { 
+          if ( inSQLXMLArray[i] == null) {
+           SQLXMLArray[i] = null; 
+          } else { 
+            if ( inSQLXMLArray[i] instanceof SQLXML ) { 
+              SQLXMLArray[i] = (SQLXML) inSQLXMLArray[i]; 
+            } else { 
+               subArrayType =
+               inSQLXMLArray[i].getClass().getName(); allValid = false; 
+            } 
+          } 
+        }
+      
+        if (allValid) { 
+          data_ =SQLXMLArray;
+        } else { 
+          if (JDTrace.isTraceOn()) { 
+            JDTrace.logInformation(this,
+                "DB2Array.validate 07006 type is SQLXML but array types is "
+                    +arrayType+" subArrayType = "+subArrayType); 
+            }
+          JDError.throwSQLException(JDError.EXC_DATA_TYPE_MISMATCH); 
+        }
+     } 
+     break;
+      
+     endif */
     case Types.TIME:
       if (JDUtilities.classIsInstanceOf(arrayComponentClass, "java.sql.Time")) {
         Time[] inTimeArray = (Time[]) inArray;
