@@ -142,6 +142,7 @@ implements IFSFileImpl
   }
 
   // @A3a
+  //@SCd //@T2C
   public int getCCSID()
     throws IOException, AS400SecurityException
   {
@@ -152,6 +153,18 @@ implements IFSFileImpl
       throw ProxyClientConnection.rethrow2 (e);
     }
   }
+  //@SCa
+  public int getCCSID(int userHandle)
+      throws IOException, AS400SecurityException
+    {
+      try {
+        return connection_.callMethod (pxId_, "getCCSID", new Class[] { Integer.TYPE },
+            new Object[] { new Integer(userHandle)}).getReturnValueInt();
+      }
+      catch (InvocationTargetException e) {
+        throw ProxyClientConnection.rethrow2 (e);
+      }
+    }
 
   public long getAvailableSpace(boolean forUserOnly)
     throws IOException, AS400SecurityException
@@ -182,6 +195,7 @@ implements IFSFileImpl
   }
 
 
+  //@SCd @T2C
   public String getOwnerName()
     throws IOException, AS400SecurityException
   {
@@ -192,8 +206,56 @@ implements IFSFileImpl
       throw ProxyClientConnection.rethrow2 (e);
     }
   }
+  //@SCa
+  public String getOwnerName(int userHandle)
+      throws IOException, AS400SecurityException
+    {
+      try {
+        return (String)connection_.callMethod (pxId_, "getOwnerName",new Class[] { Integer.TYPE },
+            new Object[] { new Integer(userHandle)}).getReturnValue();
+      }
+      catch (InvocationTargetException e) {
+        throw ProxyClientConnection.rethrow2 (e);
+      }
+    }
 
-
+  //@RDA @SAD
+  /*public int getASP()
+      throws IOException, AS400SecurityException
+    {
+      try {
+        return connection_.callMethod (pxId_, "getASP").getReturnValueInt();
+      }
+      catch (InvocationTargetException e) {
+        throw ProxyClientConnection.rethrow2 (e);
+      }
+    }*/
+  
+  //@SAA
+  public int getASP(int userHandle)
+      throws IOException, AS400SecurityException
+    {
+      try {
+        return connection_.callMethod(pxId_, "getASP", new Class[] { Integer.TYPE },
+            new Object[] { new Integer(userHandle)}).getReturnValueInt();
+      }
+      catch (InvocationTargetException e) {
+        throw ProxyClientConnection.rethrow2 (e);
+      }
+    }
+  
+  //@SAA
+  public String getFileSystemType(int userHandle)
+      throws IOException, AS400SecurityException
+    {
+      try {
+        return (String) connection_.callMethod (pxId_, "getUserHandleSeed",new Class[] { Integer.TYPE },
+            new Object[] { new Integer(userHandle)}).getReturnValue();
+      }
+      catch (InvocationTargetException e) {
+        throw ProxyClientConnection.rethrow2 (e);
+      }
+    }
   // @B7a
   public long getOwnerUID()
     throws IOException, AS400SecurityException      // @C0c
