@@ -157,7 +157,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     static final int              CONCURRENT_ACCESS_RESOLUTION  = 79; //@cc1
     static final int              JVM16_SYNCHRONIZE          = 80; //@dmy
     static final int              SOCKET_TIMEOUT              = 81; //@STIMEOUT
-    static final int              DO_UPDATE_DELETE_BLOCKING  = 82;  //@A2A
+    static final int              USE_BLOCK_UPDATE            = 82;  //@A2A
     static final int              MAXIMUM_BLOCKED_INPUT_ROWS = 83;  //@A6A
     static final int              QUERY_TIMEOUT_MECHANISM    = 84;
     static final int              DESCRIBE_OPTION            = 85;  //@F6A
@@ -165,14 +165,16 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     static final int              TIMESTAMP_FORMAT           = 87;  //@KEA 
     static final int              USE_DRDA_METADATA_VERSION  = 88; 
     static final int              QUERY_REPLACE_TRUNCATED_PARAMETER = 89;
+    static final int              NUMERIC_RANGE_ERROR        = 90; 
+    static final int              CHARACTER_TRUNCATION       = 91;  
 
     // @W2 always add to the end of the array!
 
-    private static final int    NUMBER_OF_ATTRIBUTES_ = 90;    // @A0C @C1C @A3A @D0C @E0C
+    private static final int    NUMBER_OF_ATTRIBUTES_ = 92;    // @A0C @C1C @A3A @D0C @E0C
                                                                // @E1C @D1c @E2C @E3C @E9C @F1C
                                                                // @W1c @j1c @J2c @F5C @F6C @F7c @M0C @K1C @K2C @K5C @KBC @K24 @KBL @K94 @K54 @540 @PDC
                                                                // @PDC @550 @DFA @CE1 @AC1 @igwrn @pw3 @cc1 @DMY @STIMEOUT
-                                                               // @A2C @A6C @F6A
+                                                               // @A2C @A6C @F6A@R3
 
 
     // Property names.
@@ -182,6 +184,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     private static final String BIG_DECIMAL_            = "big decimal";            // @E0A
     private static final String BLOCK_SIZE_             = "block size";
     private static final String BLOCK_CRITERIA_         = "block criteria";
+    private static final String CHARACTER_TRUNCATION_   = "character truncation"; 
     private static final String CURSOR_HOLD_            = "cursor hold";            // @D1
     private static final String CURSORHOLD_             = "CURSORHOLD";             // @D1
     private static final String CURSOR_SENSITIVITY_     = "cursor sensitivity";     // @F6A
@@ -206,6 +209,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     private static final String MAXIMUM_SCALE_          = "maximum scale";          // @M0A
     private static final String MINIMUM_DIVIDE_SCALE_   = "minimum divide scale";   // @M0A
     private static final String NAMING_                 = "naming";
+    private static final String NUMERIC_RANGE_ERROR_    = "numeric range error";    // @R3A
     private static final String PACKAGE_                = "package";
     private static final String PACKAGE_ADD_            = "package add";
     private static final String PACKAGE_CACHE_          = "package cache";
@@ -239,7 +243,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     private static final String TRANSLATE_BINARY_       = "translate binary";
     private static final String TRANSLATE_HEX_          = "translate hex";          // @M0A
     static final String USER_                           = "user";                  //@native
-    private static final String USE_DRDA_METADATA_VERSION_ = "use drda metadata version"; 
+    static final String USE_DRDA_METADATA_VERSION_ = "use drda metadata version"; 
     private static final String QAQQINILIB_             = "qaqqinilib";             // @K2A
     private static final String LOGIN_TIMEOUT_          = "login timeout";          //@K5A
     private static final String TRUE_AUTO_COMMIT_            = "true autocommit";            //@KBA //@true
@@ -264,7 +268,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
     private static final String CONCURRENT_ACCESS_RESOLUTION_ = "concurrent access resolution"; //@cc1
     private static final String JVM16_SYNCHRONIZE_ = "jvm16 synchronize"; //@dmy
     private static final String SOCKET_TIMEOUT_ = "socket timeout"; //@STIMEOUT
-    static final String DO_UPDATE_DELETE_BLOCKING_ = "use block update"; // @A2 Property must be visible in package
+    static final String USE_BLOCK_UPDATE_ = "use block update"; // @A2 Property must be visible in package
     static final String MAXIMUM_BLOCKED_INPUT_ROWS_ = "maximum blocked input rows";  // @A6A
     static final String DESCRIBE_OPTION_ = "describe option";   //@F6A
     static final String DECIMAL_DATA_ERRORS_ = "decimal data errors";
@@ -493,7 +497,15 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
 
     public static final Object QUERY_REPLACE_TRUNCATED_PARAMETER_STRING_DEFAULT = "";
 
+    public static final String NUMERIC_RANGE_ERROR_DEFAULT = "default"; 
+    public static final String NUMERIC_RANGE_ERROR_WARNING = "warning"; 
+    public static final String NUMERIC_RANGE_ERROR_NONE    = "none"; 
 
+    public static final String CHARACTER_TRUNCATION_DEFAULT = "default"; 
+    public static final String CHARACTER_TRUNCATION_WARNING = "warning"; 
+    public static final String CHARACTER_TRUNCATION_NONE    = "none"; 
+
+    
     // Static data.
     private static DriverPropertyInfo[] dpi_;
     private static String[]             defaults_;
@@ -599,6 +611,18 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
         dpi_[i].choices[7]  = BLOCK_SIZE_512;
         defaults_[i]        = BLOCK_SIZE_32;
 
+        // Numeric range error .
+        i = CHARACTER_TRUNCATION;
+        dpi_[i] = new DriverPropertyInfo (CHARACTER_TRUNCATION_, "");
+        dpi_[i].description = "CHARACTER_TRUNCATION_DESC";
+        dpi_[i].required    = false;
+        dpi_[i].choices     = new String[3];
+        dpi_[i].choices[0]  = CHARACTER_TRUNCATION_DEFAULT;
+        dpi_[i].choices[1]  = CHARACTER_TRUNCATION_WARNING;
+        dpi_[i].choices[2]  = CHARACTER_TRUNCATION_NONE;
+        defaults_[i]        = CHARACTER_TRUNCATION_DEFAULT;
+
+        
         // Cursor Hold.  @D1
         i = CURSOR_HOLD;
         dpi_[i] = new DriverPropertyInfo (CURSOR_HOLD_, "");
@@ -737,19 +761,19 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
         dpi_[i].choices[0]  = ERRORS_FULL;
         defaults_[i]        = ERRORS_BASIC;
 
-        // KeyRingName.         //@F1A
-        i = KEY_RING_NAME;
-        dpi_[i] = new DriverPropertyInfo (KEY_RING_NAME_, "");
-        dpi_[i].description = "KEY_RING_NAME_DESC";
+        // KeyRingName. Removed         //@F1A
+        i = KEY_RING_NAME; /* removed */
+        dpi_[i] = new DriverPropertyInfo ("REMOVED", "");
+        dpi_[i].description = "REMOVED";
         dpi_[i].required    = false;
         dpi_[i].choices     = new String[0];
         defaults_[i]        = EMPTY_;
 
 
-        // KeyRingPassword.          //@F1A
-        i = KEY_RING_PASSWORD;
-        dpi_[i] = new DriverPropertyInfo (KEY_RING_PASSWORD_, "");
-        dpi_[i].description = "KEY_RING_PASSWORD_DESC";
+        // KeyRingPassword.   REmoved        //@F1A
+        i = KEY_RING_PASSWORD; /*removed */ 
+        dpi_[i] = new DriverPropertyInfo ("REMOVED", "");
+        dpi_[i].description = "REMOVED";
         dpi_[i].required    = false;
         dpi_[i].choices     = new String[0];
         defaults_[i]        = EMPTY_;
@@ -810,6 +834,17 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
         dpi_[i].choices[1]  = NAMING_SYSTEM;
         defaults_[i]        = NAMING_SQL;
 
+        // Numeric range error .
+        i = NUMERIC_RANGE_ERROR;
+        dpi_[i] = new DriverPropertyInfo (NUMERIC_RANGE_ERROR_, "");
+        dpi_[i].description = "NUMERIC_RANGE_ERROR_DESC";
+        dpi_[i].required    = false;
+        dpi_[i].choices     = new String[3];
+        dpi_[i].choices[0]  = NUMERIC_RANGE_ERROR_DEFAULT;
+        dpi_[i].choices[1]  = NUMERIC_RANGE_ERROR_WARNING;
+        dpi_[i].choices[2]  = NUMERIC_RANGE_ERROR_NONE;
+        defaults_[i]        = NUMERIC_RANGE_ERROR_DEFAULT;
+
         // Package.
         i = PACKAGE;
         dpi_[i] = new DriverPropertyInfo (PACKAGE_, "");
@@ -1141,7 +1176,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
         dpi_[i].required    = false;
         dpi_[i].choices     = new String[2];
         dpi_[i].choices[0]  = TRUE_;
-        dpi_[i].choices[1]  = TRUE_;
+        dpi_[i].choices[1]  = FALSE_;
         defaults_[i]        = FALSE_;
         
 
@@ -1442,9 +1477,9 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
 
 
         // Socket timeout  //@STIMEOUT
-        i = DO_UPDATE_DELETE_BLOCKING;
-        dpi_[i] = new DriverPropertyInfo (DO_UPDATE_DELETE_BLOCKING_, "");
-        dpi_[i].description = "DO_UPDATE_DELETE_BLOCKING_DESC";
+        i = USE_BLOCK_UPDATE;
+        dpi_[i] = new DriverPropertyInfo (USE_BLOCK_UPDATE_, "");
+        dpi_[i].description = "USE_BLOCK_UPDATE_DESC";
         dpi_[i].required    = false;
         dpi_[i].choices     = new String[2];
         dpi_[i].choices[0]  = TRUE_;
@@ -1479,7 +1514,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
        //@F6A - Added RPB describe option for column names
        i = DESCRIBE_OPTION;
        dpi_[i] = new DriverPropertyInfo(DESCRIBE_OPTION_, "");
-       dpi_[i].description = "DESCRIBE_OPTION";
+       dpi_[i].description = "DESCRIBE_OPTION_DESC";
        dpi_[i].required    = false;
        dpi_[i].choices     = new String[3];
        dpi_[i].choices[0]  = DESCRIBE_OPTION_SYSTEM_NAMES;
@@ -1490,7 +1525,7 @@ class JDProperties implements Serializable, Cloneable //@PDC 550
        //@F6A - Added decimal data errors
        i = DECIMAL_DATA_ERRORS;
        dpi_[i] = new DriverPropertyInfo(DECIMAL_DATA_ERRORS_, "");
-       dpi_[i].description = "DECIMAL_DATA_ERRORS";
+       dpi_[i].description = "DECIMAL_DATA_ERRORS_DESC";
        dpi_[i].required    = false;
        dpi_[i].choices     = new String[4];
        dpi_[i].choices[0]  = DECIMAL_DATA_ERRORS_IGNORE;
