@@ -353,7 +353,9 @@ public class MessageQueue implements Serializable
     }
 
     /**
-     Closes the message list on the system.  This releases any system resources previously in use by this message list.
+     Closes the message list on the system.  
+     This releases any system resources previously in use by this message list.
+     This will not close the connection to the Host Server job held by the associated AS400 object.
      @exception  AS400SecurityException  If a security or authority error occurs.
      @exception  ErrorCompletingRequestException  If an error occurs before the request is completed.
      @exception  InterruptedException  If this thread is interrupted.
@@ -451,7 +453,9 @@ public class MessageQueue implements Serializable
     {
         if (Trace.traceOn_) Trace.log(Trace.DIAGNOSTIC, "Retrieving message queue message list.");
         // Need to get the length.
-        load();
+        if (handle_ == null || closeHandle_) //@S9A
+            load();
+
         return new QueuedMessageEnumeration(this, length_);
     }
 
