@@ -143,7 +143,12 @@ endif */
         }
 
         savedObject_ = object;
-        if(scale != -1) length_ = scale;
+        if(scale != -1) {
+          length_ = scale;
+        } else {
+            length_ = ALL_READER_BYTES; 
+            
+        } 
     }
 
     private void doConversion() throws SQLException
@@ -157,62 +162,7 @@ endif */
             }
             else if(object instanceof Reader)
             {
-                if(length_ >= 0)
-                {
-                    try
-                    {
-                        int blockSize = length_ < AS400JDBCPreparedStatement.LOB_BLOCK_SIZE ? length_ : AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1 && totalCharsRead < length_)
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-                            int charsRemaining = length_ - totalCharsRead;
-                            if(charsRemaining < blockSize)
-                            {
-                                blockSize = charsRemaining;
-                            }
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else if(length_ == -2) //@readerlen new else-if block (read all data)
-                {
-                    try
-                    {
-                        int blockSize = AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1 )
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else
-                {
-                    JDError.throwSQLException(this, JDError.EXC_DATA_TYPE_MISMATCH);
-                }
+                value_ = getStringFromReader((Reader)object, length_, this); 
             }
             else if(JDUtilities.JDBCLevel_ >= 20 && object instanceof Clob)
             {
@@ -281,7 +231,13 @@ endif */
 
     public String getJavaClassName()
     {
-        return "com.ibm.as400.access.AS400JDBCClob";
+/* ifdef JDBC40 
+      if (ccsid_ == 1200 ) {
+        return "com.ibm.as400.access.AS400JDBCNClob";
+      }
+endif */       
+      
+      return "com.ibm.as400.access.AS400JDBCClob";
     }
 
     public String getLiteralPrefix()
@@ -338,7 +294,7 @@ endif */
     {
 /* ifdef JDBC40 
       // @P3A
-      if (ccsid_ == 1200 || ccsid_ == 13400) {
+      if (ccsid_ == 1200 ) {
         return java.sql.Types.NCLOB;   
       }
 endif */       
@@ -347,12 +303,10 @@ endif */
 
     public String getTypeName()
     {
-/* ifdef JDBC40 
       // @P3A
-      if (ccsid_ == 1200 || ccsid_ == 13400) {
+      if (ccsid_ == 1200 ) {
         return "NCLOB";  
       }
-endif */       
 
         return "DBCLOB";
     }
@@ -508,7 +462,7 @@ endif */
         if(savedObject_ != null) doConversion();
         truncated_ = 0; outOfBounds_ = false;
 /* ifdef JDBC40 
-        if (ccsid_ == 1200 || ccsid_ == 13400) {
+        if (ccsid_ == 1200 ) {
            return new AS400JDBCNClob(value_, maxLength_);
         }
   endif */       
