@@ -76,6 +76,9 @@ final class SQLDBClobLocator implements SQLLocator
     public void setHandle(int handle)
     {
         locator_.setHandle(handle);
+        // @T1A reset saved handle after setting new value
+       savedObject_ = null;
+
     }
     
     //@loch
@@ -101,6 +104,8 @@ final class SQLDBClobLocator implements SQLLocator
         int locatorHandle = BinaryConverter.byteArrayToInt(rawBytes, offset);
         locator_.setHandle(locatorHandle);
         locator_.setColumnIndex(columnIndex_);
+         //  @T1A reset saved handle after setting new value
+        savedObject_ = null;
     }
 
     public void convertToRawBytes(byte[] rawBytes, int offset, ConvTable ccsidConverter)
@@ -175,62 +180,7 @@ final class SQLDBClobLocator implements SQLLocator
             }
             else if(object instanceof Reader)
             {
-                if(length_ >= 0)
-                {
-                    try
-                    {
-                        int blockSize = length_ < AS400JDBCPreparedStatement.LOB_BLOCK_SIZE ? length_ : AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1 && totalCharsRead < length_)
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-                            int charsRemaining = length_ - totalCharsRead;
-                            if(charsRemaining < blockSize)
-                            {
-                                blockSize = charsRemaining;
-                            }
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else if(length_ == -2) //@readerlen new else-if block (read all data)
-                {
-                    try
-                    {
-                        int blockSize = AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1  )
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-                             
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else
-                {
-                    JDError.throwSQLException(this, JDError.EXC_DATA_TYPE_MISMATCH);
-                }
+             value_ = SQLDataBase.getStringFromReader((Reader) object, length_, this); 
             }
             else if( object instanceof Clob)  
             {
@@ -280,7 +230,7 @@ final class SQLDBClobLocator implements SQLLocator
         }
         else if(object instanceof Reader)
         {
-            int length = scale_*2; // We are always graphic.
+            int length = scale_*2; // This is always graphic.
             // Need to write even if there are 0 bytes in case we are batching and
             // the host server reuses the same handle for the previous locator; otherwise,
             // we'll have data in the current row from the previous row.
@@ -547,7 +497,7 @@ final class SQLDBClobLocator implements SQLLocator
     {
 /* ifdef JDBC40 
       // @P3A
-      if (ccsid_ == 1200 || ccsid_ == 13400) {
+      if (ccsid_ == 1200 ) {
         return "NCLOB"; 
       }
   endif */       
@@ -593,7 +543,7 @@ final class SQLDBClobLocator implements SQLLocator
     {
 /* ifdef JDBC40 
       // @P3A
-      if (ccsid_ == 1200 || ccsid_ == 13400) {
+      if (ccsid_ == 1200 ) {
         return java.sql.Types.NCLOB;  
       }
   endif */       
@@ -627,6 +577,12 @@ final class SQLDBClobLocator implements SQLLocator
     public boolean getOutOfBounds() {
       return outOfBounds_; 
     }
+    public void clearTruncated() { 
+      truncated_ = 0; 
+    }
+    public void clearOutOfBounds() {
+      outOfBounds_ = false; 
+    }
 
     //---------------------------------------------------------//
     //                                                         //
@@ -825,6 +781,11 @@ final class SQLDBClobLocator implements SQLLocator
         return new AS400JDBCClobLocator(new JDLobLocator(locator_), converter_, savedObject_, scale_);
     }
 
+
+    public Object getBatchableObject() throws SQLException {
+      return getObject();
+    }
+
     public short getShort()
     throws SQLException
     {
