@@ -91,6 +91,8 @@ extends Cloneable
     public static final int DECFLOAT = 38;      //@DFA 
     public static final int ARRAY = 39;         //@array
     public static final int XML_LOCATOR = 40;   //@xml3
+
+    public static final int ALL_READER_BYTES = -2;
     
     /**
     Returns a clone of the SQLData object.  Use this sparingly
@@ -304,6 +306,11 @@ extends Cloneable
     **/
     public abstract int getTruncated();
     
+    /** 
+     * Clears the truncated information
+     */
+    public void clearTruncated(); 
+    
     /**
      * Returns true if the last conversion of this piece of
      * data was out of bounds of the range of the requested
@@ -311,6 +318,10 @@ extends Cloneable
      * conversion to a numeric type.  
      */
     public abstract boolean getOutOfBounds(); 
+    /** 
+     * Clear the out of bounds flag
+     */
+    public abstract void clearOutOfBounds(); 
 
     //---------------------------------------------------------//
     //                                                         //
@@ -467,6 +478,22 @@ extends Cloneable
     public abstract Object getObject()
     throws SQLException;
 
+    
+    /**
+    Converts the data to a Java object that will be used
+    later when processing a batch.  In most cases, this
+    will return the same object as getObject().
+    In the timestamp case, we return an AS400FieldedTimstamp.
+    This is need to permit timestamps that do not exist in the
+    current timezone to be sent to the server. 
+    @return             the result of the conversion.
+    @exception  SQLException    If the conversion is not
+                                required or not possible.
+    **/
+    public abstract Object getBatchableObject()
+    throws SQLException;
+
+    
     /**
     Converts the data to a Java short.
     @return     the result of the conversion.
@@ -540,6 +567,7 @@ extends Cloneable
     @return     the result of the conversion.
     @exception  SQLException    If the conversion is not
                                 required or not possible.
+    public abstract void clearOutOfBounds(); 
     **/
     public abstract String getNString()
     throws SQLException;
@@ -579,5 +607,6 @@ extends Cloneable
     public abstract Array getArray()
     throws SQLException;
 
-    public abstract void updateSettings(SQLConversionSettings settings); 
+    public abstract void updateSettings(SQLConversionSettings settings);
+
 }
