@@ -591,14 +591,24 @@ class SQLDataFactory
             case 464:                           // Graphic (pure DBCS).
                 if(ccsid == 65535)     //@bingra
                     return new SQLVargraphic((length-2)/2, settings, ccsid);  //@bingra
+                
+/* ifdef JDBC40 
+                if (ccsid == 1200)
+                  return new SQLNVarchar(length - 2, settings); //@REA 
+endif */ 
+                
                 return new SQLVargraphic(length - 2, settings, ccsid); // @C1C @C4C @cca1
 
             case 472:                           // Graphic long (pure DBCS).
-                return new SQLLongVargraphic(length - 2, settings); // @C1C @C4C
+                return new SQLLongVargraphic(length - 2, settings, ccsid); // @C1C @C4C
 
             case 468:                           // Graphic fix (pure DBCS).
                 if(ccsid == 65535)     //@bingra
                     return new SQLGraphic(length/2, settings, ccsid);  //@bingra
+/* ifdef JDBC40 
+                if (ccsid == 1200)
+                    return new SQLNChar(length, settings);  //@REA
+endif */ 
                 return new SQLGraphic(length, settings, ccsid); // @C1C @C4C @cca1
 
             case 480:                           // Float.
@@ -649,9 +659,15 @@ class SQLDataFactory
 
             case 968:                           // Dbclob locator.
             {
+              if (ccsid == 1200) { 
+                SQLNClobLocator nclob =  new SQLNClobLocator(connection, id, lobMaxSize, settings, connection.getConverter(ccsid), columnIndex); // @E1C //@F2C
+                return nclob;
+                
+              } else { 
               SQLDBClobLocator dbclob =  new SQLDBClobLocator(connection, id, lobMaxSize, settings, connection.getConverter(ccsid), columnIndex); // @E1C //@F2C
               dbclob.setCcsid(ccsid);  /*@P3A*/
-              return dbclob; 
+              return dbclob;
+              }
                 //return new SQLClobLocator(connection, id, lobMaxSize, true, settings, connection.getConverter(ccsid), columnIndex); // @E1C //@F2C
             }
              
@@ -949,4 +965,50 @@ class SQLDataFactory
         else
             return value;
     }
+
+    /* Calculate the maximum long value with the specified number of digits */ 
+    public static long getMaximumLong(int digits) {
+      long value = 0; 
+      for (int i = 0; i < digits; i++) { 
+        value = value * 10 + 9; 
+      }
+      return value; 
+    }
+    
+  public static String getMaximumString(boolean positive, int precision,int scale) {
+    StringBuffer sb = new StringBuffer();
+    if (!positive)
+      sb.append("-");
+    int leftDigits = precision - scale;
+    if (leftDigits == 0) {
+      sb.append("0");
+    } else {
+      for (int i = 0; i < leftDigits; i++) {
+        sb.append("9");
+      }
+    }
+    if (scale > 0) {
+      sb.append(".");
+      for (int i = 0; i < scale; i++) {
+        sb.append("9");
+      }
+    }
+    return sb.toString();
+  }
+    
+    public static BigDecimal getMaximumBigDecimal(int precision, int scale) {
+      /* The largest long containing 9s in all digits has 18 digits */ 
+      if (precision <= 18) {  
+          return BigDecimal.valueOf(getMaximumLong(precision), scale);
+      } else {
+          return new BigDecimal(getMaximumString(true, precision,scale)); 
+      }
+    }
+    public static BigDecimal getMinimumBigDecimal(int precision, int scale) {
+      if (precision <= 18) {  
+        return BigDecimal.valueOf(-getMaximumLong(precision), scale);
+      } else { 
+        return new BigDecimal(getMaximumString(false, precision,scale)); 
+      }
+    }
 }
