@@ -2,7 +2,7 @@
 //                                                                             
 // JTOpen (IBM Toolbox for Java - OSS version)                                 
 //                                                                             
-// Filename: SQLNclobLocator.java
+// Filename: SQLNClobLocator.java
 //                                                                             
 // The source code contained herein is licensed under the IBM Public License   
 // Version 1.0, which has been approved by the Open Source Initiative.         
@@ -37,11 +37,11 @@ final class SQLNClobLocator implements SQLLocator
 {
    
     private AS400JDBCConnection     connection_;
-    private SQLConversionSettings   settings_;
     private ConvTable               converter_;
     private int                     id_;
     private JDLobLocator            locator_;
-    private int                     maxLength_;
+    private int                     maxLength_; //note length in chars
+    private SQLConversionSettings   settings_;
     private int                     truncated_;
     private boolean                 outOfBounds_; 
     private int                     columnIndex_;
@@ -59,10 +59,10 @@ final class SQLNClobLocator implements SQLLocator
     {
         connection_     = connection;
         id_             = id;
-        locator_        = new JDLobLocator(connection, id, maxLength, false);
+        locator_        = new JDLobLocator(connection, id, maxLength, true);
         maxLength_      = maxLength;
-        truncated_ = 0; outOfBounds_ = false; 
         settings_       = settings;
+        truncated_ = 0; outOfBounds_ = false; 
         converter_      = converter;
         columnIndex_    = columnIndex;
     }
@@ -75,6 +75,9 @@ final class SQLNClobLocator implements SQLLocator
     public void setHandle(int handle)
     {
         locator_.setHandle(handle);
+        //  @T1A reset saved handle after setting new value
+       savedObject_ = null;
+
     }
     
     //@loch
@@ -100,6 +103,9 @@ final class SQLNClobLocator implements SQLLocator
         int locatorHandle = BinaryConverter.byteArrayToInt(rawBytes, offset);
         locator_.setHandle(locatorHandle);
         locator_.setColumnIndex(columnIndex_);
+        //  @T1A reset saved handle after setting new value
+       savedObject_ = null;
+
     }
 
     // This is only called from AS400JDBCPreparedStatement in one place.
@@ -129,14 +135,16 @@ final class SQLNClobLocator implements SQLLocator
         if(object instanceof String)
         {
             String s = (String)object;
-            truncated_ = (s.length() > maxLength_ ? s.length()-maxLength_ : 0);
+            int length = s.length(); 
+            truncated_ = (length > maxLength_ ? length-maxLength_ : 0);  
             outOfBounds_ = false;
         } 
         //@PDD jdbc40 (JDUtilities.JDBCLevel_ >= 20 incorrect logic, but n/a now
         else if( !(object instanceof Reader) &&
            !(object instanceof InputStream) &&
            !(object instanceof Clob) 
-/*ifdef JDBC40            
+/*ifdef JDBC40 
+           && !(object instanceof NClob)
            && !(object instanceof SQLXML)
            endif */ 
            
@@ -174,68 +182,7 @@ final class SQLNClobLocator implements SQLLocator
             }
             else if(object instanceof Reader)
             {
-                if(length_ >= 0)
-                {
-                    try
-                    {
-                        int blockSize = length_ < AS400JDBCPreparedStatement.LOB_BLOCK_SIZE ? length_ : AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1 && totalCharsRead < length_)
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-                            int charsRemaining = length_ - totalCharsRead;
-                            if(charsRemaining < blockSize)
-                            {
-                                blockSize = charsRemaining;
-                            }
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-
-                        if(value_.length() < length_)
-                        {
-                            // a length longer than the stream was specified
-                            JDError.throwSQLException(this, JDError.EXC_DATA_TYPE_MISMATCH);
-                        }
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else if(length_ == -2) //@readerlen new else-if block (read all data)
-                {
-                    try
-                    {
-                        int blockSize = AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
-                        Reader stream = (Reader)object;
-                        StringBuffer buf = new StringBuffer();
-                        char[] charBuffer = new char[blockSize];
-                        int totalCharsRead = 0;
-                        int charsRead = stream.read(charBuffer, 0, blockSize);
-                        while(charsRead > -1)
-                        {
-                            buf.append(charBuffer, 0, charsRead);
-                            totalCharsRead += charsRead;
-                            
-                            charsRead = stream.read(charBuffer, 0, blockSize);
-                        }
-                        value_ = buf.toString();
-                    }
-                    catch(IOException ie)
-                    {
-                        JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
-                    }
-                }
-                else
-                {
-                    JDError.throwSQLException(this, JDError.EXC_DATA_TYPE_MISMATCH);
-                }
+              value_ = SQLDataBase.getStringFromReader((Reader)object, length_, this); 
             }
             else if( object instanceof Clob)  
             {
@@ -277,19 +224,12 @@ final class SQLNClobLocator implements SQLLocator
             if(object instanceof String)
             {
                 String string = (String)object;
-                int bidiStringType = settings_.getBidiStringType();
-                if(bidiStringType == -1) bidiStringType = converter_.bidiStringType_;
-
-                BidiConversionProperties bidiConversionProperties = new BidiConversionProperties(bidiStringType); 
-                bidiConversionProperties.setBidiImplicitReordering(settings_.getBidiImplicitReordering());       
-                bidiConversionProperties.setBidiNumericOrderingRoundTrip(settings_.getBidiNumericOrdering());   
-
-                byte[] bytes = converter_.stringToByteArray(string, bidiConversionProperties); 
-                locator_.writeData(0L, bytes, true);              
+            byte[] bytes = converter_.stringToByteArray(string);
+            locator_.writeData(0L, bytes, true);            //@k1C
             }
             else if(object instanceof Reader)
             {
-                int length = scale_; // hack to get the length into the set method
+                int length = scale_ * 2; // This is always graphic
                 // Need to write even if there are 0 bytes in case we are batching and
                 // the host server reuses the same handle for the previous locator; otherwise,
                 // we'll have data in the current row from the previous row.
@@ -317,7 +257,7 @@ final class SQLNClobLocator implements SQLLocator
                             int bytesRead = stream.read(byteBuffer, 0, blockSize);
                             while(bytesRead > -1 && totalBytesRead < length)
                             {
-                                locator_.writeData((long)totalBytesRead, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset. 
+                                locator_.writeData((long)(totalBytesRead/2), byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset. 
                                 totalBytesRead += bytesRead;
                                 int bytesRemaining = length - totalBytesRead;
                                 if(bytesRemaining < blockSize)
@@ -325,13 +265,14 @@ final class SQLNClobLocator implements SQLLocator
                                     blockSize = bytesRemaining;
                                     if(stream.available() == 0 && blockSize != 0)
                                     {
+                                    	stream.close(); 
                                         stream = new ReaderInputStream((Reader)savedObject_, converter_.getCcsid(), bidiConversionProperties, blockSize); // do this so we don't read more chars out of the Reader than we have to. //@KBC changed to use bidiConversionProperties instead of bidiStringType
                                     }
                                 }
                                 bytesRead = stream.read(byteBuffer, 0, blockSize);
                             }
 
-
+                           
                             if(totalBytesRead < length)
                             {
                                 // a length longer than the stream was specified
@@ -351,7 +292,7 @@ final class SQLNClobLocator implements SQLLocator
                         JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
                     }
                 }
-                else if(length == -2) //@readerlen new else-if block (read all data)
+                else if(length == ALL_READER_BYTES) //@readerlen new else-if block (read all data)
                 {
                     try
                     {
@@ -371,7 +312,7 @@ final class SQLNClobLocator implements SQLLocator
                             int bytesRead = stream.read(byteBuffer, 0, blockSize);
                             while(bytesRead > -1 )
                             {
-                                locator_.writeData((long)totalBytesRead, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset. 
+                                locator_.writeData((long)(totalBytesRead/2), byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset. 
                                 totalBytesRead += bytesRead;
                                
                                 bytesRead = stream.read(byteBuffer, 0, blockSize);
@@ -398,7 +339,7 @@ final class SQLNClobLocator implements SQLLocator
             }
             else if(object instanceof InputStream)
             {
-                int length = scale_; // hack to get the length into the set method
+                int length = scale_ * 2; // We are always graphic
                 // Need to write even if there are 0 bytes in case we are batching and
                 // the host server reuses the same handle for the previous locator; otherwise,
                 // we'll have data in the current row from the previous row.
@@ -417,7 +358,7 @@ final class SQLNClobLocator implements SQLLocator
                         int bytesRead = stream.read(byteBuffer, 0, blockSize);
                         while(bytesRead > -1 && totalBytesRead < length)
                         {
-                            locator_.writeData((long)totalBytesRead, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset.  
+                            locator_.writeData((long)totalBytesRead/2, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset.  
                             totalBytesRead += bytesRead;
                             int bytesRemaining = length - totalBytesRead;
                             if(bytesRemaining < blockSize)
@@ -439,7 +380,7 @@ final class SQLNClobLocator implements SQLLocator
                         JDError.throwSQLException(this, JDError.EXC_INTERNAL, ie);
                     }
                 }
-                else if(length == -2) //@readerlen new else-if block (read all data)
+                else if(length == ALL_READER_BYTES) //@readerlen new else-if block (read all data)
                 {
                     InputStream stream = (InputStream)savedObject_;
                     int blockSize = AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
@@ -450,7 +391,7 @@ final class SQLNClobLocator implements SQLLocator
                         int bytesRead = stream.read(byteBuffer, 0, blockSize);
                         while(bytesRead > -1 )
                         {
-                            locator_.writeData((long)totalBytesRead, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset.  
+                            locator_.writeData((long)totalBytesRead/2, byteBuffer, 0, bytesRead, true); // totalBytesRead is our offset.  
                             totalBytesRead += bytesRead;
                            
                             bytesRead = stream.read(byteBuffer, 0, blockSize);
@@ -496,10 +437,20 @@ final class SQLNClobLocator implements SQLLocator
                 {
                     Clob clob = (Clob)object;
                     int length = (int)clob.length();
-                    String substring = clob.getSubString(1, length);
-                    // @J5C Use length of output array not substring
-                    byte[] outByteArray = converter_.stringToByteArray(substring);
-                    locator_.writeData(0L, outByteArray, 0, outByteArray.length, true);         
+                int blockSize = AS400JDBCPreparedStatement.LOB_BLOCK_SIZE;
+                if(length < blockSize) blockSize = length;
+                int position = 1;
+                AS400JDBCClobLocator thisClob = new AS400JDBCClobLocator(new JDLobLocator(locator_), converter_, savedObject_, scale_);   //@hloc1 getClob() returns local value since it was just set.  Here we want the locator on the host so we can write to it. 
+                while(position <= length)
+                {
+                    String substring = clob.getSubString(position, blockSize);
+                    thisClob.setString(position, substring);
+                    position += blockSize;
+                    if((length - position) < blockSize)
+                    {
+                        blockSize = length - position + 1;
+                    }
+                }
                     set = true;
                 }
                 else
@@ -548,7 +499,7 @@ endif */
 
     public int getDisplaySize()
     {
-        return maxLength_;
+        return maxLength_ / 2;
     }
 
     public String getJavaClassName()
@@ -573,7 +524,7 @@ endif */
 
     public int getMaximumPrecision()
     {
-        return AS400JDBCDatabaseMetaData.MAX_LOB_LENGTH; //@xml3 // the DB2 SQL reference says this should be 2147483647 but we return 1 less to allow for NOT NULL columns
+        return 1073741822; // the DB2 SQL reference says this should be 1073741823 but we return 1 less to allow for NOT NULL columns
     }
 
     public int getMaximumScale()
@@ -588,7 +539,7 @@ endif */
 
     public int getNativeType()
     {
-        return 964;        
+        return 968;        
     }
 
     public int getPrecision()
@@ -618,12 +569,7 @@ endif */
 
     public String getTypeName()
     {
-    	/* ifdef JDBC40 
         return "NCLOB";
-        endif */ 
-    	/* ifndef JDBC40 */ 
-    	return "CLOB"; 
-    	/* endif */ 
     }
 
     public boolean isSigned()
@@ -650,6 +596,13 @@ endif */
       return outOfBounds_; 
     }
 
+    public void clearTruncated() { 
+      truncated_ = 0; 
+    }
+    public void clearOutOfBounds() {
+      outOfBounds_ = false; 
+    }
+
     //---------------------------------------------------------//
     //                                                         //
     // CONVERSIONS TO JAVA TYPES                               //
@@ -715,8 +668,15 @@ endif */
         truncated_ = 0; outOfBounds_ = false; 
         try
         {
-            byte[] bytes = BinaryConverter.stringToBytes(getString());
-            return new AS400JDBCBlob(bytes, bytes.length);
+        	   if(savedObject_ != null)//@loch
+            {                       //@loch
+                //get value from RS.updateX(value)
+                doConversion();     //@loch
+                truncated_ = 0; outOfBounds_ = false;      //@loch
+                return  new AS400JDBCBlob(BinaryConverter.stringToBytes(value_), maxLength_);
+            }                       //@loch
+            
+            return new AS400JDBCBlob(BinaryConverter.stringToBytes(getString()), maxLength_);
         }
         catch(NumberFormatException nfe)
         {
@@ -846,6 +806,14 @@ endif */
         /* endif */ 
     }
 
+
+  
+
+
+    public Object getBatchableObject() throws SQLException {
+      return getObject();
+    }
+
     public short getShort()
     throws SQLException
     {
@@ -905,7 +873,7 @@ endif */
         }
         catch(UnsupportedEncodingException e)
         {
-            JDError.throwSQLException(JDError.EXC_INTERNAL, e);
+            JDError.throwSQLException(this, JDError.EXC_INTERNAL, e);
             return null;
         }
     }
