@@ -14,6 +14,7 @@
 package com.ibm.as400.access;
 
 import java.io.InputStream;
+import java.io.Reader;
 import java.io.StringReader;
 import java.sql.Blob;
 import java.sql.Clob;
@@ -40,6 +41,7 @@ extends SQLDataBase  implements SQLVariableCompressible
     protected int                     maxLength_;
     protected String                  value_;
     protected int                     bytesPerCharacter_; 
+    protected int                     sizeAfterTruncation_ = 0; 
 
     // Note: maxLength is in bytes not counting 2 for LL.
     //
@@ -92,6 +94,7 @@ extends SQLDataBase  implements SQLVariableCompressible
             // If the field is VARGRAPHIC, length_ contains the number
             // of characters in the string, while the converter is expecting
             // the number of bytes. Thus, we need to multiply length_ by bytesPerCharacter.
+            sizeAfterTruncation_ = length_*bytesPerCharacter_; 
             value_ = ccsidConverter.byteArrayToString(rawBytes, offset+2, length_*bytesPerCharacter_, bidiConversionProperties);   //@KBC changed to use bidiConversionProperties instead of bidiStringType
         }catch(Exception e){
             JDError.throwSQLException(JDError.EXC_CHAR_CONVERSION_INVALID, e);
@@ -111,17 +114,26 @@ extends SQLDataBase  implements SQLVariableCompressible
             BidiConversionProperties bidiConversionProperties = new BidiConversionProperties(bidiStringType);  //@KBA
             bidiConversionProperties.setBidiImplicitReordering(settings_.getBidiImplicitReordering());         //@KBA
             bidiConversionProperties.setBidiNumericOrderingRoundTrip(settings_.getBidiNumericOrdering());      //@KBA
-
+            truncated_ = 0; outOfBounds_ = false ; 
+            
             // The length in the first 2 bytes is actually the length in characters.
             byte[] temp = ccsidConverter.stringToByteArray(value_, bidiConversionProperties);   //@KBC changed to used bidiConversionProperties instead of bidiStringType
             BinaryConverter.unsignedShortToByteArray(temp.length/bytesPerCharacter_, rawBytes, offset);
+            sizeAfterTruncation_ = temp.length; 
             if(temp.length > maxLength_)
             {
+                sizeAfterTruncation_ = maxLength_; 
                 truncated_ = temp.length - maxLength_;  /*@H2C*/
-                maxLength_ = temp.length;
-                JDError.throwSQLException(this, JDError.EXC_INTERNAL, "Change Descriptor");
+                // Not sure why maxLength_ was changed. 
+                // maxLength_ = temp.length;
+                // We now set the truncated information and let the truncated data through
+                // JDError.throwSQLException(this, JDError.EXC_INTERNAL, "Change Descriptor");
+                // the testDataTruncation method will be called to see if
+                // the truncation message should be thrown. 
+                System.arraycopy(temp, 0, rawBytes, offset+2, maxLength_);
+            } else { 
+              System.arraycopy(temp, 0, rawBytes, offset+2, temp.length);
             }
-            System.arraycopy(temp, 0, rawBytes, offset+2, temp.length);
 
             // The buffer we are filling with data is big enough to hold the entire field.
             // For varchar fields the actual data is often smaller than the field width.
@@ -168,7 +180,7 @@ extends SQLDataBase  implements SQLVariableCompressible
             if(temp.length > maxLength_)
             {
                 truncated_ = temp.length - maxLength_;  /*@H2C*/
-                maxLength_ = temp.length;
+                // maxLength_ = temp.length;
                 JDError.throwSQLException(this, JDError.EXC_INTERNAL, "Change Descriptor");
             }
             if (temp.length > 0)  {
@@ -229,7 +241,11 @@ extends SQLDataBase  implements SQLVariableCompressible
             Clob clob = (Clob)object;                                              // @C1C
             value = clob.getSubString(1, (int)clob.length());                      // @C1C  @D1
         }                                                                     // @C1C
-             
+        else if(object instanceof Reader)
+        {
+          value = getStringFromReader((Reader) object, ALL_READER_BYTES, this);
+        }
+            
         /* ifdef JDBC40 
         else if(object instanceof SQLXML) //@PDA jdbc40 
         {    
@@ -356,9 +372,14 @@ extends SQLDataBase  implements SQLVariableCompressible
         return true;
     }
 
+    // Returns the size after truncation has occurred 
     public int getActualSize()
     {
+      if (sizeAfterTruncation_ != 0) {
+        return sizeAfterTruncation_; 
+      } else { 
         return value_.length();
+      }
     }
 
     public int getTruncated()
