@@ -150,6 +150,26 @@ public class SystemPoolBeanInfo extends SimpleBeanInfo
             poolSize.setDisplayName(loader_.getText("PROP_NAME_SP_POOLSIZE"));
             poolSize.setShortDescription(loader_.getText("PROP_DESC_SP_POOLSIZE"));
             
+            //@S4A
+            PropertyDescriptor poolSizeLong = new PropertyDescriptor("poolSizeLong", beanClass_, 
+                "getSizeLong", "setSizeLong"); 
+            poolSizeLong.setBound(true);
+            poolSizeLong.setConstrained(true);
+            String namePoolSizeLong; 
+            try { 
+              namePoolSizeLong = loader_.getText("PROP_NAME_SP_POOLSIZELONG");
+            } catch (java.util.MissingResourceException e) { 
+              namePoolSizeLong = loader_.getText("PROP_NAME_SP_POOLSIZE");
+            }
+            poolSizeLong.setDisplayName(namePoolSizeLong);
+            String descPoolSizeLong; 
+            try { 
+              descPoolSizeLong = loader_.getText("PROP_DESC_SP_POOLSIZELONG");
+            } catch (java.util.MissingResourceException e) { 
+              descPoolSizeLong = loader_.getText("PROP_DESC_SP_POOLSIZE");
+            }
+            poolSizeLong.setShortDescription(descPoolSizeLong);
+            
             PropertyDescriptor reservedSize = new PropertyDescriptor("reservedSize", beanClass_, 
                                                                      "getReservedSize", null); 
             reservedSize.setBound(false);
